@@ -1,6 +1,6 @@
 package Sque::Job;
 {
-  $Sque::Job::VERSION = '0.002';
+  $Sque::Job::VERSION = '0.003';
 }
 use Any::Moose;
 use Any::Moose '::Util::TypeConstraints';
@@ -88,11 +88,19 @@ sub queue_from_class {
 sub perform {
     my $self = shift;
     $self->class->require || confess $@;
-    $self->class->can('perform')
-        || confess $self->class . " doesn't know how to perform";
 
-    no strict 'refs';
-    &{$self->class . '::perform'}($self);
+    # First test if its OO
+    if($self->class->can('new')){
+        no strict 'refs';
+        $self->class->new->perform( $self );
+    }else{
+        # If it's not OO, just call perform
+        $self->class->can('perform')
+            || confess $self->class . " doesn't know how to perform";
+
+        no strict 'refs';
+        &{$self->class . '::perform'}($self);
+    }
 }
 
 __PACKAGE__->meta->make_immutable();
@@ -109,7 +117,7 @@ Sque::Job - Sque job container
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 ATTRIBUTES
 
